@@ -46,7 +46,7 @@ extern SEXP _transport_cgal_present(void);
 extern SEXP _transport_semidiscrete_p1(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _transport_cplex_present(void);
 extern SEXP _transport_SolveHierarchicalTransport(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _transport_networkflow(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _transport_networkflow(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _transport_gen_cost(SEXP, SEXP, SEXP);
 extern SEXP _transport_gen_cost0(SEXP, SEXP);
 extern SEXP _transport_gen_cost0d(SEXP, SEXP);
@@ -77,7 +77,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"_transport_semidiscrete_p1", (DL_FUNC) &_transport_semidiscrete_p1, 6},
     {"_transport_cplex_present", (DL_FUNC) &_transport_cplex_present, 0},
     {"_transport_SolveHierarchicalTransport", (DL_FUNC) &_transport_SolveHierarchicalTransport, 13},
-    {"_transport_networkflow", (DL_FUNC) &_transport_networkflow, 4},
+    {"_transport_networkflow", (DL_FUNC) &_transport_networkflow, 5},
     {"_transport_gen_cost", (DL_FUNC) &_transport_gen_cost, 3},
     {"_transport_gen_cost0", (DL_FUNC) &_transport_gen_cost0, 2},
     {"_transport_gen_cost0d", (DL_FUNC) &_transport_gen_cost0d, 2},
